@@ -200,7 +200,7 @@ int mapobject::parse(const ST::string & c)
   if (pos >= 0)
 	 (*functions[pos])(*this);
 
-  return pos;
+  return(pos);
   }
 
 
