@@ -1533,7 +1533,7 @@ FULLCOND_nonp_gaussian::FULLCOND_nonp_gaussian(MCMCoptions * o,
     if (ce==false)
       identifiable = true;
     else
-      identifiable = false;  
+      identifiable = false;
 
     varcoeff = true;
 
@@ -1613,7 +1613,7 @@ FULLCOND_nonp_gaussian::FULLCOND_nonp_gaussian(MCMCoptions * o,
     *workX = *workx;
     workX++;
     *workX = *worky;
-    *workX++;
+    workX++;
     }
 
   MAP::map m(
@@ -2768,7 +2768,7 @@ void FULLCOND_nonp_gaussian::update_IWLS_mode(void)
   if (notransform==false)
     transform = likep->get_trmult(column);
   else
-    transform = 1;  
+    transform = 1;
 
 
   FULLCOND::update();
@@ -3117,7 +3117,10 @@ void FULLCOND_nonp_gaussian::update(void)
 
 // Multiplikative Effekte: Zentrieren des Effekts
     if (notransform)
-      double m = centerbeta();
+      {
+      double m = 0.0;
+      m = centerbeta();
+      }
 
     update_linpred(true);
 
@@ -3529,14 +3532,15 @@ bool FULLCOND_nonp_gaussian::posteriormode(void)
   precenv.solve(beta);
 
 // Multiplikative Effekte: Zentrieren des Effekts
+  double m = 0.0;
   if (notransform)
-    double m = centerbeta();
+    m = centerbeta();
 
   update_linpred(true);
 
   if (center)
     {
-    double m = centerbeta();
+    m = centerbeta();
     if (varcoeff)
       fcconst->posteriormode_fix_varcoeff(m,datanames[1]);
     else
