@@ -197,7 +197,7 @@ void FULLCOND_random::compute_XWX(const datamatrix & weightmat,
                                   const unsigned & col)
   {
 
-  register unsigned j,i;
+   unsigned j,i;
 
   double * workXX = XX.getV();
   int *  workindex = index.getV();
@@ -237,7 +237,7 @@ double FULLCOND_random::compute_quadform(void)
   unsigned n;
   double sum = 0;
   double * workbeta = beta.getV();
-  register unsigned i;
+   unsigned i;
 
   if (randomslope && includefixed)
     n = nrpar-1;
@@ -1901,7 +1901,7 @@ void FULLCOND_random_nongaussian::update_random_intercept(void)
   FULLCOND_random::update();
 
 
-  update_spatialtotal();  
+  update_spatialtotal();
 
 
   }
