@@ -125,6 +125,8 @@ FC_nonp::FC_nonp(MASTER_OBJ * mp,unsigned & enr, GENERAL_OPTIONS * o,DISTR * lp,
 
   read_options(op,vn);
 
+  multiplicative = false;
+
   multf=false;
 
   imeasures=false;
@@ -193,6 +195,10 @@ FC_nonp::FC_nonp(const FC_nonp & m)
   multf=m.multf;
   multf_value=m.multf_value;
 
+  multiplicative = m.multiplicative;
+  multlikep = m.multlikep;
+  expetatilde = m.expetatilde;
+
   imeasures=m.imeasures;
 
   masterp = m.masterp;
@@ -253,6 +259,10 @@ const FC_nonp & FC_nonp::operator=(const FC_nonp & m)
   multf=m.multf;
   multf_value=m.multf_value;
 
+  multiplicative = m.multiplicative;
+  multlikep = m.multlikep;
+  expetatilde = m.expetatilde;
+
   imeasures=m.imeasures;
 
   masterp = m.masterp;
@@ -350,8 +360,8 @@ void FC_nonp::update_IWLS(void)
   unsigned i;
   double * workparam;
 
-//  lambda = likep->get_scale()/tau2;
-  lambda = 1/tau2;
+  lambda = likep->get_scale()/tau2;
+//  lambda = 1/tau2;
 
   if (optionsp->nriter == 1)
     {
@@ -544,7 +554,9 @@ void FC_nonp::ssvs_update(double & tauratio, bool signswitch, bool onlyupdate)
 
 void FC_nonp::update(void)
   {
-  set_multiplicative();
+  if(multiplicative)
+    get_multiplicative();
+
   if (IWLS)
     {
     update_IWLS();
@@ -558,7 +570,10 @@ void FC_nonp::update(void)
     else
       {
       if(likep->gamlss)
-        double logold = likep->compute_iwls(true,false);
+        {
+        double logold = 0.0;
+        logold = likep->compute_iwls(true,false);
+        }
       update_gaussian();
       }
     }
@@ -573,6 +588,10 @@ void FC_nonp::update(void)
     meaneffect_sample.update();
     }
 
+  if(multiplicative)
+    {
+    designp->compute_effect(multlikep->fx,beta,MCMC::Function);
+    }
   }
 
 
@@ -956,13 +975,17 @@ void FC_nonp::update_isotonic(void)
 
 bool FC_nonp::posteriormode_transform(void)
   {
-  set_multiplicative();
+  if(multiplicative)
+    get_multiplicative();
 
   double h = likep->compute_iwls(true,false);
 
   betaold.assign(beta);
 
-  designp->compute_partres(partres,beta,true);
+  if(likep->dgexists)
+    designp->compute_partres_multiplicative(partres,beta,true);
+  else
+    designp->compute_partres(partres,beta,true);
 
   if (designp->QtRinv.rows() <= 1)
     {
@@ -1013,24 +1036,34 @@ bool FC_nonp::posteriormode_transform(void)
                               meaneffect_sample.beta,computemeaneffect,
                               meaneffectconstant);
 
-  return FC::posteriormode();
 
+  if(multiplicative)
+    {
+    designp->compute_effect(multlikep->fx,beta,MCMC::Function);
+    }
+
+  return FC::posteriormode();
   }
 
 bool FC_nonp::posteriormode(void)
   {
-  set_multiplicative();
+  if(multiplicative)
+    get_multiplicative();
 
   if (orthogonal)
     return posteriormode_transform();
   else
     {
 
-    double h = likep->compute_iwls(true,false);
+    double h = 0.0;
+    h = likep->compute_iwls(true,false);
 
     betaold.assign(beta);
-    designp->compute_partres(partres,beta,true);
 
+    if(likep->dgexists)
+      designp->compute_partres_multiplicative(partres,beta,true);
+    else
+      designp->compute_partres(partres,beta,true);
 
     designp->compute_XtransposedWX();
 
@@ -1108,6 +1141,15 @@ bool FC_nonp::posteriormode(void)
 
     }
 
+  if(multiplicative)
+    {
+    designp->compute_effect(multlikep->fx,beta,MCMC::Function);
+
+/*    ofstream out("c:/temp/fx.raw");
+    (multlikep->fx).prettyPrint(out);
+    out.close();*/
+    }
+
   return FC::posteriormode();
   }
 
@@ -2323,16 +2365,36 @@ void FC_nonp::get_samples(const ST::string & filename,ofstream & outg) const
 
   }
 
-void FC_nonp::set_multiplicative(void)
+void FC_nonp::set_multiplicative(DISTR * dp)
   {
-  if(likep->multintvar.rows()>1)
-    {
-    designp->changingdesign=true;
-    designp->set_intvar(likep->multintvar,0);
-    designp->meaneffectintvar = 1;
-    }
+  multiplicative = true;
+  designp->changingdesign=true;
+  multlikep = dp;
+  expetatilde = datamatrix(likep->nrobs,1,1.0);
   }
 
+void FC_nonp::get_multiplicative(void)
+  {
+  double * worklin;
+  if (multlikep->linpred_current==1)
+    worklin = multlikep->linearpred1.getV();
+  else
+    worklin = multlikep->linearpred2.getV();
+  double * etildep = expetatilde.getV();
+  unsigned i;
+
+  for(i=0; i<likep->nrobs; i++, worklin++, etildep++)
+    *etildep = exp(*worklin);
+
+/*  ofstream out1("c:/temp/etatilde.raw");
+  (multlikep->linearpred1).prettyPrint(out1);
+  out1.close();
+  ofstream out2("c:/temp/expetatilde.raw");
+  expetatilde.prettyPrint(out2);
+  out2.close();*/
+
+  designp->set_intvar(expetatilde);
+  }
 
 void FC_nonp::reset(void)
   {
