@@ -30,7 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include"distr.h"
 
 #if defined(BayesX_gsl_included)
-#include "gsl/gsl_randist.h"
+#include "gsl_randist.h"
 #endif
 
 namespace MCMC
